@@ -15,14 +15,6 @@ class ParallelFunction(ParalellyFunction):
     def _serial_func(self, arg_list, kwarg_list):
         return [self._func(*args, **kwargs) for args, kwargs in zip(arg_list, kwarg_list)]
 
-    def _chunks(self, elements, n):
-        def chunker(elements, n):
-            steps = len(elements) // n
-            for i, index in enumerate(range(0, len(elements), steps)):
-                yield elements[index : index + steps] if i != n else elements[index:]
-
-        return list(chunker(elements, n))
-
     def map(self, *args, **kwargs):
         args, kwargs = prepare_arguments(args, kwargs)
         pool_size = min(self._max_workers, len(args))
@@ -30,8 +22,8 @@ class ParallelFunction(ParalellyFunction):
         with Pool(pool_size) as pool:
             results = []
 
-            arg_chunks = self._chunks(args, pool_size)
-            kwarg_chunks = self._chunks(kwargs, pool_size)
+            arg_chunks = self._batch(args, groups=pool_size)
+            kwarg_chunks = self._batch(kwargs, groups=pool_size)
             for chunk in pool.map(self._serial_func, arg_chunks, kwarg_chunks):
                 results += chunk
 
