@@ -8,6 +8,10 @@ from parallely.utils import prepare_arguments
 
 
 class ThreadedFunction(ParalellyFunction):
+    def __init__(self, func: Callable, max_workers: int, batch_size: Optional[int]):
+        super().__init__(func, max_workers)
+        self._batch_size = batch_size
+
     def _execute_once(self, *args, **kwargs) -> Any:
         return self._func(*args, **kwargs)
 
@@ -19,19 +23,21 @@ class ThreadedFunction(ParalellyFunction):
         pool_size = min(self._max_workers, len(args))
 
         with ThreadPoolExecutor(pool_size) as pool:
-            futures = [pool.submit(self._execute_once, *arg, **kwarg) for arg, kwarg in zip(args, kwargs)]
-            for future in futures:
-                yield future.result() 
+            for b_args, b_kwargs in zip(self._batch(args, steps=self._batch_size), self._batch(kwargs, steps=self._batch_size)):
+                futures = [pool.submit(self._execute_once, *arg, **kwarg) for arg, kwarg in zip(b_args, b_kwargs)]
+                for future in futures:
+                    yield future.result() 
 
     def acmap(self, *args, **kwargs) -> List[Any]:
         args, kwargs = prepare_arguments(args, kwargs)
         pool_size = min(self._max_workers, len(args))
 
         with ThreadPoolExecutor(pool_size) as pool:
-            for future in as_completed([pool.submit(self._execute_once, *arg, **kwarg) for arg, kwarg in zip(args, kwargs)]):
-                yield future.result()
+            for b_args, b_kwargs in zip(self._batch(args, steps=self._batch_size), self._batch(kwargs, steps=self._batch_size)):
+                for future in as_completed([pool.submit(self._execute_once, *arg, **kwarg) for arg, kwarg in zip(b_args, b_kwargs)]):
+                    yield future.result()
 
-def threaded(func: Callable = None, max_workers: Optional[int] = None) -> ThreadedFunction:
+def threaded(func: Callable = None, max_workers: Optional[int] = None, batch_size: Optional[int] = None) -> ThreadedFunction:
     """
 
     :param func:
@@ -40,8 +46,9 @@ def threaded(func: Callable = None, max_workers: Optional[int] = None) -> Thread
     """
 
     max_workers = max_workers if max_workers is not None else cpu_count() * 10
+    batch_size =  batch_size if batch_size is not None else  4 * max_workers
 
     if func is None:
-        return partial(threaded, max_workers=max_workers)
+        return partial(threaded, max_workers=max_workers, batch_size=batch_size)
 
-    return ThreadedFunction(func, max_workers)
+    return ThreadedFunction(func, max_workers, batch_size)
